@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  19 July 2011
+#  Last change:  6 October 2013
 #
 # Includes contributions by
 #  - Matt Martin (matt.martin _AT_ ieee.org) marked "MGM contribution"
@@ -880,11 +880,17 @@ proc ScanDate {date} {
 	return [list $y $m $d 0 0 0]
     }
     set goodn -1
-    if { [regexp {^ *([-0-9]+)T([0-9:.]+)([^ ]+) *$} $date m ymd hms tail] } {
+    # includes VR contribution: decimal comma, empty tail
+    if { [regexp {^ *([-0-9]+)T([0-9:]+([.,][0-9]+)?)([^ ]*) *$} \
+	     $date m ymd hms m tail] } {
 	# coping with ISO8601 format as in:
 	#   2000-01-01T12:00:00Z
 	#   2000-01-01T12:00:00.00000Z
 	#   2004-06-07T13:51:27.2515650-07:00
+	#   2009-09-23T07:02:46.773
+	#   2009-09-23T07:02:46,773
+	# must replace decimal comma by period
+	regsub {,} $hms "." hms
 	set n 1
 	if { [scan $hms %02d:%02d:%0f h mn s] == 3 && \
 		 [scan $ymd %4d-%02d-%02d y m d] == 3 } {
@@ -918,7 +924,15 @@ proc ScanDate {date} {
 		# convert to local date
 		foreach "y m d h mn s" \
 		    [LocalTimeAndUTC $y $m $d $h $mn $s UTC] {}
-	    } elseif { $tail == "Z" } { set goodn 1 }
+	    } elseif { $tail == "Z" } {
+		set goodn 1
+		# convert to local date
+		foreach "y m d h mn s" \
+		    [LocalTimeAndUTC $y $m $d $h $mn $s UTC] {}
+	    } elseif { $tail == "" } {
+		# local time : should convert to UTC 
+		set goodn 1 
+	    }
 	}
     } else {
 	set l [split $date -] ; set n [llength $l]
