@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: config.tcl
-#  Last change:  15 September 2011
+#  Last change:  6 October 2013
 #
 
 ## the following values can be set from the options dialog of the interface
@@ -334,6 +334,11 @@ array set COUTFMT {
     GRA    %.5f
 }
 
+  # whether GPSMan data file can be appended to an existing file when saving
+  # WARNING: this may create a file with conflicting time offsets that cannot
+  #  be loaded by GPSMan
+set APPGMDATAFILE 0
+
   # echo on password fields, either "none" or a single character
 set PASSWDECHO *
 
