@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  10 October 2011
+#  Last change:  6 October 2013
 #
 # See also files_foreign.tcl
 #  and metadata.tcl for properties of known file formats
@@ -705,16 +705,20 @@ proc SaveFileTo {f how what args} {
     # save information to file $f in GPSMan format
     # if $f=="" ask user to select output file
     # if $f!="stdout" file will be closed at the end
-    # only when $how=="comp" file can be appended to if it exists
+    # file can be appended to if it exists only when $how=="comp" or
+    #  $APPGMDATAFILE is non-zero
     # see proc SaveFile for the description of the arguments
-    global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS File
+    global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS File \
+	APPGMDATAFILE
 
     set stypes $TYPES
     if { $SUPPORTLAPS } { lappend stypes LAP }
     if { $how == "state" } {
 	set slow 0
     } else { set slow 1 }
-    set mode w
+    if { $APPGMDATAFILE } {
+	set mode wapp
+    } else { set mode w }
     switch $how {
 	all -  state {
 	    set lp [AllIndicesForType $what $stypes]
