@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: gendials.tcl
-#  Last change:  27 December 2009
+#  Last change:  6 October 2013
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb_AT_onthenet.com.au) marked "BSB contribution"
@@ -488,7 +490,7 @@ proc SaveDisplayInfo {wtxt} {
     global TXT
 
     if { [set txt [$wtxt get 1.0 end]] == "" || \
-	     [set f [GMOpenFile $TXT(saveto) Info w]] == ".." } { return }
+	     [set f [GMOpenFile $TXT(saveto) Info wapp]] == ".." } { return }
     puts $f $txt
     close $f
     return
@@ -642,7 +644,7 @@ proc GMOpenFile {act wh mode} {
     # create modal dialog for selecting and opening a file
     #  $act is string describing the action to do on the file
     #  $wh in $filetypes (see proc GMStart, setup.tcl)
-    #  $mode in {r, w}
+    #  $mode in {r, w, wapp} with wapp meaning write or possibly append
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
     global GMResult COLOUR DPOSX DPOSY LISTHEIGHT File TXT MESS UNIX
@@ -650,6 +652,7 @@ proc GMOpenFile {act wh mode} {
     if { [set f $File($wh)] == "" || [catch {cd [file dirname $f]}] } {
 	set currfile ""
     } else { set currfile [file tail $f] }
+    if { $mode == "wapp" } { set mode a }
 
     GMToplevel .fdlg file +$DPOSX+$DPOSY . \
         {WM_DELETE_WINDOW {set GMResult cnc}} \
@@ -753,6 +756,7 @@ proc GMOpenFileParms {act wh mode vars vals} {
 
     set fname [GMGetFileName $act $wh $mode $vars $vals]
     if { $fname == ".." } { return ".." }
+    if { $mode == "wapp" } { set mode a }
     return [open $fname $mode]
 }
 
@@ -760,7 +764,7 @@ proc GMGetFileName {act wh mode vars vals} {
     # create modal dialog for selecting a file name and parameters
     #  $act is string describing the action to do on the file
     #  $wh in $filetypes (see proc GMStart, setup.tcl)
-    #  $mode in {r, w}
+    #  $mode in {r, w, wapp} with wapp meaning write or possibly append
     #  $vars is list of (global) vars to set
     #  $vals is associated list of value descriptions (see proc GMSetupParams)
     #  buttons: OK, Cancel
@@ -865,6 +869,7 @@ proc GMGetFileName {act wh mode vars vals} {
 		set f [GMCheckFile check $fn $mode]
 		if { $f != ".." } {
 		    set File($wh) [file join [pwd] $fn]
+		    GMUseEntries .fdlg.fr.fopt $es
 		    set res $fn
 		    break
 		}
@@ -880,7 +885,7 @@ proc GMCheckFile {how f mode} {
     # check name of file $f and if ok either open it and return file descriptor
     #  or return file name; otherwise return ".."
     #  $how in {open check}
-    #  $mode in {r, w}
+    #  $mode in {r, w, wapp}
     global PERMS TXT MESS
 
     if { $f == "" } { bell ; return ".." }
@@ -900,25 +905,30 @@ proc GMCheckFile {how f mode} {
 		open { return [open $f r] }
 		check { return $f }
 	    }
-	} else {
-	    bell
-	}
+	} else { bell }
     } elseif { [file exists $f] } {
 	if { [file writable $f] } {
-	    set m [GMSelect $MESS(filexists) \
-		    [list $TXT(ovwrt) $TXT(app) $TXT(cancel)] "w a 0"]
-	    if { $m != 0 } {
+	    if { $mode == "w" } {
+		set l [list $TXT(ovwrt) $TXT(cancel)]
+		set r {w 0}
+	    } else {
+		# appending is an option
+		set l [list $TXT(ovwrt) $TXT(app) $TXT(cancel)]
+		set r {w a 0}
+	    }
+	    if { [set m [GMSelect $MESS(filexists) $l $r]] != 0 } {
 		switch $how {
 		    open { return [open $f $m $PERMS] }
 		    check { return $f }
 		}
 	    }
-	} else {
-	    bell
-	}
+	} else { bell }
     } elseif { [file writable [pwd]] } {
 	switch $how {
-	    open { return [open $f $mode $PERMS] }
+	    open {
+		if { $mode == "wapp" } { set mode a }
+		return [open $f $mode $PERMS]
+	    }
 	    check { return $f }
 	}
     } else {
@@ -1074,6 +1084,8 @@ proc GMSetupParams {w vars descs} {
     #    array elements may also be given instead of normal variables but
     #    the indices must be alphanumeric
     #  $descs is associated list of value descriptions as:
+    #      @@TEXT  button creating a balloon help with $TXT(TEXT), associated
+    #         variable declared as global but not used nor set
     #      @TEXT   checkbutton with label TEXT, values 0 1
     #      =@TEXT  non-echo entry with label TEXT
     #      =TEXT   entry with label TEXT
@@ -1106,6 +1118,12 @@ proc GMSetupParams {w vars descs} {
 	global $vname
 	frame $w.f$i
 	switch -glob -- $os {
+	    @@* {
+		set os [string replace $os 0 1]
+		set bh $w.f$i.bh$vid
+		BalloonButton $bh $os
+		pack $bh
+	    }
 	    @* {
 		set os [string replace $os 0 0]
 		set cb $w.f$i.c$vid
@@ -1327,7 +1345,7 @@ proc ImageListbox {act path args} {
 	    regsub {,csize$} $n "" lbox
 	    destroy $lbox
 	}
-	foreach n [array names GMIBox $path*] { unset GMIBox($n) }
+	array unset GMIBox $path*
 	return
     }
     if { [set nargs [llength $args]] != 0 } {
