@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: know.tcl
-#  Last change:  19 July 2011
+#  Last change:  6 October 2013
 #
 # Includes contributions by Brian Baulch (baulchb_AT_onthenet.com.au)
 #  marked "BSB contribution"
@@ -197,9 +197,7 @@ proc UnsetAll {wh} {
     # see GMStart (setup.tcl) for description of data arrays
     global Storage IndexOf
 
-    foreach n [array names IndexOf $wh,*] {
-	unset IndexOf($n)
-    }
+    array unset IndexOf $wh,*
     foreach arr $Storage($wh) {
 	global $arr
 
@@ -762,7 +760,7 @@ proc SamePosn {ix data} {
 	set p [ToDatum [lindex $p 0] [lindex $p 1] $d $WPDatum($ix)]
     }
     if { [ComputeDist $p $WPPosn($ix) $WPDatum($ix)] < 0.003 } { return 1 }
-    return [lreplace $p 2 end $WPDatum($ix)]
+    return [list [lindex $p 0] [lindex $p 1] $WPDatum($ix)]
 }
 
 proc AddToNB {nb txt} {
