@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,11 +19,11 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  22 December 2009
-# German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
+#  Last change:  6 October 2013
+# German language file by Andreas Lange (Andreas.C.Lange _AT_ GMX.de)
 #  last input from him inserted: 31 January 2002
 #
-# Support by Sabine Broda (sbb@ncc.up.pt) since 2002
+# Support by Sabine Broda (sbb _AT_ dcc.fc.up.pt) since 2002
 #  last input from her inserted:  22 December 2009
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -1238,7 +1240,7 @@ array set TXT {
     chgdev "Gert wechseln"
     maxalt "Maximalhhe"
     minalt "Mindesthhe"
-    alt_cumul "Anstiegssumme"
+    alt_cumula "Anstiegssumme"
     alt_cumuld "Abstiegssumme"
     optSHOWFILEITEMS "Normalerweise werden gelesene Elemente in der Karte gezeigt"
     vertgridlines "Gittervertikale"
@@ -1329,3 +1331,8 @@ array set INVTXT {
     GR   GR
 }
 
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
