@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  16 September 2011
+#  Last change:  6 October 2013
 #
 # French language file by Valre Robin (valere.robin _AT_ wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  27 December 2009
+#  last input from him inserted:  12 October 2011
 #
 # Includes contributions by Jean H Theoret (ve2za _AT_ rac.ca)
 # Includes contributions by Benoit Steiner (benetsteph _AT_ free.fr)
@@ -304,7 +304,21 @@ array set MESS {
     badpluginparam "Mauvais paramtre du greffon : liste d'expressions de NAME EXPR, NAME commence par _"
     badpluginparamexec "Lors de l'excution du greffon %s, mauvais paramtre: %s"
     pluginfailed "Echec du greffon %s avec le message: %s"
-    canwrtaux "Impossibilit d'crire le fichier auxiliaire"
+    cantwrtdir "Ecriture sur %s impossible; permissions  changer"
+    cantcleandir "Nettoyage du rpertoire %s impossible"
+    defTERMCMD "L'option permettant d'ouvrir une fentre de commande doit tre dfinie au pralable."
+    gpOutfile "Le rsultat est dans le fichier \"%s\" dans le rpertoire de travail."
+    gpQuitgnuplot "Appuyer sur la touche Entre pour quitter GnuPlot."
+    gpModgnuplot "Modifiez la visualisation dans la fentre GnuPlot\
+   		 en dplaant la souris (bouton de gauche ou du milieu)\n\
+		 Aprs la fermeture de la fentre GnuPlot, le rsultat\
+		 sera dans le fichier \"%s\" du rpertoire de travail."
+    htResult1 "Traces=\"%s\""
+    htResult2 "Distance totale=%s  Monte totale=%s  Descente totale=%s"
+    htResult3 "Dure totale=%s Dure des pauses=%s(%s)  Dure des dplacements=%s"
+    htResult4 "%s  Cap.  plat=%s  Cap. monte=%s  Cap. descente=%s  Est. temps de marche=%s"
+    srResult1 "Pauses (>5min) de la trace \"%s\""
+    badcumuls "Diffrence d'altitude %s > total des montes %s et/ou descente %s; l'option sur le seuil d'altitude % % devrait tre modifie"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -1352,6 +1366,61 @@ array set TXT {
     plugin  "Greffon"
     unavailif  "Indisponible si"
     tclcode  "Code TCL"
+    PRJSphMerc "Sphrique Mercator"
+    PRJEPSG:3857 "EPSG:3857"
+    PRJEqCyl "Cylindrique quidistante"
+    PRJEPSG:32663 "EPSG:32663"
+    gpTRtoGnuplot2d "Vue de cot (Gnuplot)"
+    gpTRtoGnuplot2d_nb "Envoi de la trace  GNUPLOT et affichage du profil d'altitude"
+    gpTRtoGnuplot3d "Perspective (Gnuplot)"
+    gpTRtoGnuplot3d_nb "Envoi de la trace  GNUPLOT et affichage du profil 3D"
+    gpParam2d "Paramtres pour Gnuplot 2D-Chart"
+    gpParam3d "Paramtres pour Gnuplot 3D-Chart"
+    gpFilename "Nom du fichier"
+    gpCanwidth   "Largeur de la zone de dessin"
+    gpCanheight  "Hauteur de la zone de dessin"
+    gpSTotals  "Affichage des totaux"
+    gpLeft  "Cot gauche"
+    gpRight "Cot droit"
+    gpNone  "Sans objet"
+    gpSRests "Affichage des pauses"
+    gpRest  "Pause"
+    gpSymText "Symbole+Texte"
+    gpSymTime "Symbole+Heure"
+    gpText  "Texte"
+    gpSHours "Affichage des heures"
+    gpTimetop "Heure en haut"
+    gpTimebot "Heure en bas"
+    gpSSpeed "Affichage des vitesses"
+    gpHike  "Marche"
+    gpBike  "Vlo"
+    gpDrive "Voiture"
+    gpGlide "Planeur"
+    gpLimitDist "Distance max entre WP et trace (km)"
+    gpLimitStat "Longueur minimale sur la trace pour un mme WP (km)"
+    gpDirection "Direction"
+    gpForward "Avant"
+    gpBackward "Arrire"
+    gp2D_hlp "S'il existe un groupe de mme nom que la trace,\n\
+              les points d'itinraires du groupe seront affichs\n\ 
+	      en fonction des distances fournies.\n\
+              Sinon, vous pouvez choisir dans une liste ou annuler."
+    gpGenerated "Produit avec gnuplot par GPSMan"
+    gpModify "Modifier la vue avec la souris. Quitter pour sauver l'image."
+    htCalcHikeTime "Calcul de la dure de la marche"
+    htCalcHikeTime_nb "Calcul de la dure de la marche avec formule de DAV"
+    htHeader "Temps de marche estime (sans les pauses) pour les traces\
+               en utilisant les formules de \"Deutscher Alpenverein\"\
+	       avec diffrents paramtres"
+    htFooter1 "Capacit fait rfrence  une heure."
+    htFooter2 "Le temps de pause propos est de 20 minutes toutes les 2 heures."
+    srShowRest_nb "Affichage des pauses de plus de 5 minutes."
+    srTRTime   "Dure de la trace"
+    srTotals   "Totaux"
+    optALTHRESHOLD "Seuil d'altitude"
+    optDISPLAYCMD "Commande pour afficher une image"
+    optTERMCMD "Commande pour ouvrir une fentre de saisie de commandes"
+    optMANHTTPADDR "Adresse HTTP du manuel utilisateur"
 }
 
     # the following definitions must be coherent with $TXT
