@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  16 September 2011
+#  Last change:  6 October 2013
 #  Italian language file by Alessandro Palmas (alpalmas _AT_ tin.it)
-#  last input from him inserted:  22 December 2009
+#  last input from him inserted:  16 October 2011
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -301,7 +301,18 @@ array set MESS {
     badpluginparam  "Parametri plug-in errati: lista di NAME EXPR, NAME inizia con _"
     badpluginparamexec "Durante l'esecuzione del plug-in %s, incontrato parametro errato: %s"
     pluginfailed "Plug-in %s fallisce con messaggio: %s"
-    canwrtaux "Impossibile scrivere file ausiliario"
+    cantwrtdir "Impossibile scrivere su %s; controllare i permessi"
+    cantcleandir "Pulizia directory non possibile %s"
+    defTERMCMD "L'opzione per il comando che apre una finestra emulazione terminale deve essere definita prima"
+    gpOutfile "L'output  nel file \"%s\" nella vostra directory di lavoro."
+    gpQuitgnuplot "Premere Invio nella finestra xterm per abbandonare gnuplot." 
+    gpModgnuplot "Modica vista in finestra gnuplot." 
+    htResult1 "Traccia=\"%s\""
+    htResult2 "Distanza totale=%s  Salita totale=%s  Discesa totale=%s"
+    htResult3 "Tempo totale impiegato=%s  Tempo sosta=%s(%s)  Tempo movimento=%s"
+    htResult4 "%s  Cap.piano=%s  Cap.sal=%s  Cap.disc=%s  Est. tempo marcia=%s"
+    srResult1 "Periodi di sosta (>5min) della traccia \"%s\""
+    badcumuls "Differenza in altitudine %s > salita totale %s e/o discesa %s; soglia altitudine opzionale %s %s andrebbe modificata"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -1293,6 +1304,62 @@ Twitter con etichetta #GPSMan #waypoint"
     plugin  "Plug-in"
     unavailif  "Non disponibile se"
     tclcode  "Codice Tcl"
+    PRJSphMerc "Sferica di Mercatore"
+    PRJEPSG:3857 "EPSG:3857"
+    PRJEqCyl "Cilindrica Equidistante "
+    PRJEPSG:32663 "EPSG:32663"
+    gpTRtoGnuplot2d "Vista di lato-view (Gnuplot)"
+    gpTRtoGnuplot2d_nb "Invia i dati della traccia al programma esterno GNUPLOT e produci grafico elevazione" 
+    gpTRtoGnuplot3d "Prospettiva (Gnuplot)"
+    gpTRtoGnuplot3d_nb "Invia i dati della traccia al programma esterno GNUPLOT e produci grafico 3-D" 
+    gpParam2d "Parametri per grafico Gnuplot 2D"
+    gpParam3d "Parametri per grafico Gnuplot 3D"
+    gpFilename "Nome file"
+    gpCanwidth   "Larghezza Canvas"
+    gpCanheight  "Altezza Canvas"
+    gpSTotals  "Mostra totali"
+    gpLeft  "Lato sinistro"
+    gpRight "Lato destro"
+    gpNone  "Nessuno"
+    gpSRests "Mostra soste"
+    gpRest  "Sosta"
+    gpSymText "Simbolo+Testo"
+    gpSymTime "Simbolo+Tempo"
+    gpText  "Testo"
+    gpSHours "Mostra ore"
+    gpTimetop "Tempo in alto"
+    gpTimebot "Tempo in basso"
+    gpSSpeed "Mostra velocit"
+    gpHike  "Piedi"
+    gpBike  "Bici"
+    gpDrive "Motore"
+    gpGlide "Aliante"
+    gpLimitDist "Max. Distanza WP da Traccia (km)"
+    gpLimitStat "Min. Lunghezza su Traccia per stesso WP (km)"
+    gpDirection "Direzione"
+    gpForward "Avanti"
+    gpBackward "Indietro"
+    gp2D_hlp "Se esiste un nome di gruppo identico al nome della traccia,\n\
+              i waypoint di tale gruppo verranno mostrati,\n\
+              in considerazione delle distanze date.\n\
+              Quando non esiste un nome di gruppo corrispondente,\
+              si pu sceglierne uno da lista o uscire (cancel)."
+    gpGenerated "Generato da GPSMan con gnuplot"
+    gpModify "Modicare la vista con il mouse . Abbandonare per salvare il disegno."
+    htCalcHikeTime "Calcolare il Tempo di Cammino"
+    htCalcHikeTime_nb "Calcolare il Tempo di  Cammino con formula DAV"
+    htHeader "Tempo stimato di cammino (senza soste) per tracce\
+               usando la formula di \"Deutscher Alpenverein\"\
+               con parametri differenti"
+    htFooter1 "La Capacit si riferisce ad un ora."
+    htFooter2 "Il tempo di sosta consigliato  20min ogni due ore (15%)."
+    srShowRest_nb "Mostra periodi di sosta > 5min."
+    srTRTime   "Tempo traccia"
+    srTotals   "Totali"
+    optALTHRESHOLD "Soglia elevazione"
+    optDISPLAYCMD "Comando per mostrare file immagine"
+    optTERMCMD "Comando per aprire finestra terminale"
+    optMANHTTPADDR "Indirizzo HTTP del Manuale Utente"
 }
 
     # the following definitions must be coherent with $TXT
