@@ -3,13 +3,15 @@
 #
 #  Copyright (c) 2007 Nikolai Kosyakov ()
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c)1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -21,10 +23,10 @@
 #      along with this program.
 #
 #  File: langru.tcl
-#  Last change:  27 December 2009
+#  Last change:  6 October 2013
 # Russian language file by Nikolai Kosyakov, 21 October 2007
 #
-# Support by Alexander B. Preobrazhenskiy, (modul@ihome.ru) since October 2009
+# Support by Alexander B. Preobrazhenskiy (modul_AT_ihome.ru) since October 2009
 #  last input from him inserted:  27 December 2009
 #
 
@@ -1370,7 +1372,7 @@ array set TXT {
     chgdev "Сменить прибор"
     maxalt "Максимальная высота"
     minalt "Минимальная высота"
-    alt_cumul "Нарастающая высота восхождения"
+    alt_cumula "Нарастающая высота восхождения"
     alt_cumuld "Нарастающая величина спуска"
     optSHOWFILEITEMS "По умолчанию отображать на карте читаемые элементы"
     vertgridlines "Вертикальные линии сетки"
@@ -1406,4 +1408,9 @@ array set INVTXT {
     фут   FT
 }
 
+# changes by Miguel Filgueiras to RM contribution
+set TXT(srChainage) $TXT(totdst)
+set TXT(srShowRest) $TXT(gpSRests)
+set TXT(gpSym) $TXT(symbol)
+set TXT(srRest) $TXT(gpRest)
 
