@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 1998-2010 Miguel Filgueiras migf _AT_ portugalmail.pt Universidade do Porto
+#  Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  15 September 2011
+#  Last change:  6 October 2013
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -134,7 +134,7 @@ set OPTVALS(DISTUNIT) {KM NAUTMILE STATMILE}
 set OPTTYPE(ALTUNIT) oneof
 set OPTVALS(ALTUNIT) {M FT}
 
-set OPTTYPE(ALTHRESHOLD) nat
+set OPTTYPE(ALTHRESHOLD) float
 
 set OPTTYPE(PositionFormat) fixedmenu
 set OPTMENUCONTS(PositionFormat) $PFORMATS
@@ -353,7 +353,7 @@ proc SetOptions {} {
 			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTTYPE($v) $val] } {
-				GMMessage "$TXT(wrgval) $TXT(opt$v)"
+				GMMessage "$MESS(wrgval) $TXT(opt$v)"
 				set ok 0 ; break
 			    }
 			    set $v $val
