@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,11 +19,11 @@
 #      along with this program.
 #
 #  File: projs_main.tcl
-#  Last change:  17 June 2009
+#  Last change:  6 October 2013
 #
 
 # Includes contributions by
-#  - Sandor Laky (laky.sandor_AT_freemail.hu) marked "SL contribution"
+#  - Sandor Laky (laky.sandor_at_freemail.hu) marked "SL contribution"
 #  - Miguel Filgueiras (to code by others) marked "MF contribution/change"
 
 ### most of this code used to be at the end of file projections.tcl
@@ -156,7 +158,7 @@ proc ProjInit {proj data datum ps} {
 	    set ${data}(lat0) 0
 	}
 	Merc1 {
-	    # Mercator projection, single parallel
+	    # Mercator projection, single parallel, ellipsoidal case
 	    # take average of longitudes as central longitude, and use k0=1
 	    set ${data}(long0) [AverageLong $longd $datum $ps]
 	    set ${data}(k0) 1.0
@@ -170,14 +172,15 @@ proc ProjInit {proj data datum ps} {
 	    if { abs($lamin) > $lamax } { set lamax [expr abs($lamin)] }
 	    set ${data}(lat1) $lamax
 	}
-	CS {
-	    # Cassini-Soldner projection
-	    # take averages of latitudes and longitudes as central coordinates
+	SphMerc -  CS {
+	    # Mercator projection, single parallel, spherical case
+            #  and Cassini-Soldner projection
+	    # take average of longitudes and longitudes as central coordinates
 	    foreach "${data}(lat0) ${data}(long0)" \
 		    [AverageLatLong $latd $longd $datum $ps] {}
 	}
-	APOLY {
-	    # American Polyconic projection
+	APOLY -  EqCyl {
+	    # American Polyconic and Equidistant Cylindrical projections
 	    # take averages of latitudes as standard latitude
 	    set ${data}(lat0) [AverageLat $latd $datum $ps]
 	}
@@ -255,7 +258,7 @@ proc BadProjSetup {data proj latd longd datum} {
 	TM -  BMN -  CTR -  EOV -  GKK -  KKJP -  TWG {
 	}
 	LCC1 -  Stereogr -  SOM -  LCC2 -  AEA -
-	LEAC -  Merc1 -  Merc2 -  CS -  APOLY {
+	LEAC -  Merc1 -  Merc2 -  SphMerc -  CS -  APOLY -  EqCyl {
 	    set aux 1
 	}
 	default {
@@ -274,7 +277,6 @@ proc AverageExtrLatLong {latd longd datum ps} {
     #  the first
     # return list with the two averages followed by the maximum and the minimum
 
-    set n 1
     set n 1
     set sla [set lamx [set lamn $latd]] ; set slo $longd
     foreach p [lreplace $ps 0 0] {
@@ -448,7 +450,7 @@ proc ProjTMInvert {data x y} {
 }
 
 ## German Grid (Gauss-Krueger-Koordinatensystem) projection
-# Information provided by Andreas Lange (Andreas.C.Lange@GMX.de)
+# Information provided by Andreas Lange (Andreas.C.Lange_at_GMX.de)
 # This is a Transverse Mercator projection with zone in [0-6], lat0=0,
 #  lon0=zone*3 (0, 3, 6, 9, 12, 15E), and scale factor at central meridian
 #  of k0=1.0
@@ -457,7 +459,7 @@ proc ProjTMInvert {data x y} {
 # Similar with zone in [1-4], lon0=zone*3+18 (21, 24, 27, 30E)
 
 # Taiwan Grid projection
-# Information provided by Dan Jacobson (jidanni@yahoo.com.tw)
+# Information provided by Dan Jacobson (jidanni_at_yahoo.com.tw)
 # Similar with zone in [1-6], lon0=zone*2+113 (115, 117, ..., 125E),
 #  and k0=0.9999
 
@@ -1064,6 +1066,54 @@ proc ProjMerc2Invert {data x y} {
     return [ProjMerc1Invert $data $x $y]
 }
 
+## Mercator projection: a special case of Lambert Conic Conformal
+#   with the equator as standard parallel
+
+# single standard parallel, spherical case
+# adapted from libproj 4.6.1
+
+proc ProjSphMercComputeAux {data datum} {
+    # compute auxiliary parameters from main parameters
+    #  $data is name of global array for the parameters
+    global $data
+
+    set a [lindex [EllipsdData $datum] 0]
+    set lat0 [set ${data}(lat0)]
+    if { $lat0 > 1e-15 } {
+	set k0 [expr cos($lat0*0.01745329251994329576)]
+    } else { set k0 1 }
+    set ${data}(m_a) [expr 1.0*$a*$k0]
+    return
+}
+
+proc ProjSphMercPoint {data latd longd datum} {
+    # compute planar Cartesian coordinates for given position
+    global $data
+
+    set prdatum [set ${data}(datum)]
+    if { $datum != $prdatum } {
+	foreach "latd longd" \
+		[ToDatum $latd $longd $datum $prdatum] { break }
+    }
+    set long0 [set ${data}(long0)]
+    set longd [NormalLongCentred $longd $long0]
+    set x [expr [set ${data}(m_a)]*($longd-$long0)*0.01745329251994329576]
+    set y [expr [set ${data}(m_a)]* \
+	       log(tan(0.78539816339744830962+$latd*0.00872664625997164788))]
+    return [list $x $y]
+}
+
+proc ProjSphMercInvert {data x y} {
+    # return list with latitude and longitude for point at $x,$y in the terrain
+    global $data
+
+    set latd [expr (1.5707963267948966-2*atan(exp(-$y/[set ${data}(m_a)]))) * \
+		57.29577951308232087684]
+    set longd [expr $x/[set ${data}(m_a)]*57.29577951308232087684+ \
+	            [set ${data}(long0)]]
+    return [list $latd [NormalLong $longd]]
+}
+
 ## Cassini-Soldner projection
 
 proc ProjCSComputeAux {data datum} {
@@ -1230,6 +1280,44 @@ proc ProjAPOLYInvert {data x y} {
     return [list $latd $longd]
 }
 
+## Equidistant Cylindrical projection
+# adapted from libproj 4.6.1
+
+proc ProjEqCylComputeAux {data datum} {
+    # compute auxiliary parameters from main parameters
+    #  $data is name of global array for the parameters
+    global $data
+
+    set a [set ${data}(m_a) [lindex [EllipsdData $datum] 0]]
+    set ${data}(m_0) [expr cos([set ${data}(lat0)]*0.01745329251994329576)*$a]
+    return
+}
+
+proc ProjEqCylPoint {data latd longd datum} {
+    # compute planar Cartesian coordinates for given position
+    global $data
+
+    set prdatum [set ${data}(datum)]
+    if { $datum != $prdatum } {
+	foreach "latd longd" \
+		[ToDatum $latd $longd $datum $prdatum] { break }
+    }
+    set x [expr [set ${data}(m_0)]*$longd*0.01745329251994329576]
+    set y [expr [set ${data}(m_a)]*($latd-[set ${data}(lat0)])* \
+	       0.01745329251994329576]
+    return [list $x $y]
+}
+
+proc ProjEqCylInvert {data x y} {
+    # return list with latitude and longitude for point at $x,$y in the terrain
+    global $data
+
+    set latd [expr $y/[set ${data}(m_a)]*57.29577951308232087684+ \
+		  [set ${data}(lat0)]]
+    set longd [expr $x/[set ${data}(m_0)]*57.29577951308232087684]
+    return [list $latd [NormalLong $longd]]
+}
+
 ## auxiliary procs for polyconic projection
 # meridional distance for ellipsoid and inverse
 
