@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,9 +19,9 @@
 #      along with this program.
 #
 #  File: util.tcl
-#  Last change:  18 December 2009
+#  Last change:  6 October 2013
 #
-# Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
+# Includes contributions by Brian Baulch (baulchb _AT_ onthenet.com.au)
 #  marked "BSB contribution"
 #
 
@@ -490,8 +492,21 @@ proc FillDir {w} {
 
 ## operations on windows
 
+proc CloseWindows {ws} {
+    # close windows using their specific WM_DELETE_WINDOW command if any
+
+    foreach w $ws {
+	if { [winfo exists $w] } {
+	    if { [set c [wm protocol $w WM_DELETE_WINDOW]] != "" } {
+		catch {eval $c}
+	    } else { destroy $w }
+	}
+    }
+    return
+}
+
 proc DestroyRGrabs {w oldgrabs} {
-    destroy window $w and restore previous grabs
+    # destroy window $w and restore previous grabs
 
     destroy $w
     foreach w $oldgrabs {
